@@ -6,10 +6,12 @@ class Listener : public QObject{
 public slots:
      void updateTasks();
      void chFile();
-     void chanSel(int idx);
+     void chanSel();
      void taskSel(int idx);
+     void taskClicked();
      void ftSel(int idx);
-     void saveTask();
+     void guiToTasks();
+     void saveTasks();
      void delTask();
      void newTask();
      void immAbb();
