@@ -25,6 +25,7 @@ Ui_ConfigDlg *confDlg=NULL;
 QIcon nowI;
 QIcon doneI;
 QIcon todoI;
+QIcon notsavedI;
 QFileSystemWatcher *fsw;
 
 #define HSADDON_H_DEF
@@ -54,6 +55,10 @@ QString addOnPath="./addons";
 #endif
 
 
+bool ignoreChanges = false;
+
+void noUnsavedChanges();
+void unsavedChanges();
 
 void fillTasks(QListWidget *taskList);
 void Listener::updateTasks(){
@@ -80,7 +85,7 @@ void Listener::chFile(){
 void Listener::immAbb(){
 	int row=0;
 	if(hkMain->taskList->currentRow() < 0){
-		saveTask();
+		saveTasks();
 	} else
 		row = hkMain->taskList->currentRow();
 	logS << "immAbb" << endl;
@@ -109,7 +114,24 @@ void Listener::immAbb(){
 
 }
 
-void Listener::saveTask(){
+void Listener::saveTasks(){
+	int row = hkMain->taskList->currentRow();
+	logS << "saveTask" << endl;
+
+	writeTasks();
+	tasksToCrontab();
+	
+	readTasks();
+	fillTasks(hkMain->taskList);
+
+	noUnsavedChanges();
+	taskSel(row);
+	return;
+}
+
+void Listener::guiToTasks(){
+	if(ignoreChanges)
+		return;
 	int row=0;
 	if(hkMain->taskList->currentRow() < 0){
 		newTask();
@@ -129,30 +151,28 @@ void Listener::saveTask(){
 	tk->title = hkMain->titleEdit->toPlainText();
 	tk->status = (int) !hkMain->doneCB->isChecked();
 	tk->doFinalCmd = hkMain->finalCmdCB->isChecked();
-	tk->unsaved = false;
+	tk->unsaved = true;
 	if(hkMain->chanBox->currentIndex() >= 0){
 		tk->chanMnemo = channels[hkMain->chanBox->currentIndex()].mnemo;
 		tk->chanType = channels[hkMain->chanBox->currentIndex()].type;
 	}
-	writeTasks();
-	tasksToCrontab();
-	hkMain->taskList->setCurrentRow(row);
-	hkMain->taskList->currentItem()->setText(*new QString(tk->title)+ " (" + tk->author+ " " 
-			+ tk->chanMnemo + "       " + tk->start.toString("dd.MM.   hh:mm") + ")");
-	hkMain->taskList->currentItem()->setIcon(tk->status == NOW ? nowI : tk->status == DONE ?
-		doneI : todoI);
+	unsavedChanges();
+	hkMain->taskList->currentItem()->setText(tk->title+ " (" + tk->author+ " " 
+	+ tk->chanMnemo + "       " + tk->start.toString("dd.MM.   hh:mm") + ")");
+	hkMain->taskList->currentItem()->setIcon(notsavedI);
 	
 	hkMain->immAbb->setText(tk->status == NOW ? tr("Anhalten") : tr("sofort starten"));
-	hkMain->immAbb->setIcon(tk->status == NOW ? todoI : nowI);
-	return;
 }
 
+
 void Listener::newTask(){
 	errorS << "newTask" << endl;
 	Task *tk = new Task;
 	tk->jobNumber = getNextJobNum();
-	hkMain->taskList->addItem(*new QString("neu"));
+	hkMain->taskList->addItem(new QListWidgetItem(notsavedI,tk->title));
 	tasks.append(*tk);
+	taskSel(hkMain->taskList->count()-1);
+	unsavedChanges();
 	return;
 }
 
@@ -162,13 +182,18 @@ void Listener::delTask(){
 	errorS << "delTask" << endl;
 	tasks.removeAt(hkMain->taskList->currentRow());
 	hkMain->taskList->clearSelection();
+	hkMain->taskSpecificBox->setEnabled(false);
 	errorS << hkMain->taskList->currentRow() << endl;
 	hkMain->taskList->takeItem(hkMain->taskList->currentRow());	
 	writeTasks();
+	#ifdef Q_WS_MAEMO_5
+	hkMain->page_2->hide();
+	#endif
 	return;
 }
 
 void Listener::taskSel(int idx){
+	ignoreChanges = true;
 	errorS << "taskSel: " << idx << endl;
 	/*it's very important to check this, because takeitem
 	causes a rowChanged signal!*/
@@ -194,18 +219,32 @@ void Listener::taskSel(int idx){
 		hkMain->chanBox->setCurrentIndex(i);
 	hkMain->ftBox->setCurrentIndex(tk.ft+1);
 	hkMain->fqBox->setCurrentIndex(tk.fq);
+	#ifndef Q_WS_MAEMO_5
 	hkMain->calendar->setSelectedDate(hkMain->start->date());
+	#endif
 	hkMain->JobNumL->setNum(tk.jobNumber);
 	hkMain->doneCB->setChecked(!tk.status);
 	hkMain->finalCmdCB->setChecked(tk.doFinalCmd);
 	hkMain->immAbb->setText(tk.status == NOW ? tr("Anhalten") : tr("sofort starten"));
 	hkMain->immAbb->setIcon(tk.status == NOW ? todoI : nowI);
+	
+	hkMain->taskSpecificBox->setEnabled(true);
+	hkMain->taskList->setCurrentRow(idx);
+	ignoreChanges = false;
 	return;
 }
 
-void Listener::chanSel(int idx){
+void Listener::taskClicked(){
+	#ifdef Q_WS_MAEMO_5
+	hkMain->page_2->setAttribute(Qt::WA_Maemo5StackedWindow);
+	hkMain->page_2->setWindowFlags(hkMain->page_2->windowFlags() | Qt::Window);
+	hkMain->page_2->show();
+	#endif
+}
+
+void Listener::chanSel(){
 	ftSel(hkMain->ftBox->currentIndex());
-	errorS << idx << endl;
+	guiToTasks();
 	return;
 }
 
@@ -238,12 +277,16 @@ void Listener::ftSel(int idx){
 	QString suff = (ft != -1) ? suffixes[ft] : "";
 	hkMain->fileEdit->clear();
 	hkMain->fileEdit->insertPlainText(file+suff);
+	guiToTasks();
 	return;
 }
 
 void Listener::dateChanged(){
-	hkMain->doneCB->setChecked(false);
+	if(hkMain->start->dateTime() > hkMain->stop->dateTime())
+		hkMain->stop->setDateTime(hkMain->start->dateTime());
+	guiToTasks();
 	errorS << "date changed" << endl;
+	//unsavedChanges();
 	return;
 }
 
@@ -313,6 +356,11 @@ void Listener::respMenuAction(QAction* qa){
 		Ui_AbtDlg *ad = new Ui_AbtDlg;
 		
 		ad->setupUi(qd);
+		QString html = ad->textBrowser->toHtml();
+		html.replace("HSKISTEVERSION",HSKISTEVERSION);
+		html.replace("HSKISTEYEARS",HSKISTEYEARS);
+		ad->textBrowser->setHtml(html);
+		
 		//stacked Window
 		#ifdef Q_WS_MAEMO_5
 		qd->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -438,11 +486,21 @@ void Listener::saveConfig(){
 	monthBeforeDay = confDlg->monthBefDayCB->isChecked();
 	useSchtasks = confDlg->useSchtasksCB->isChecked();
 #endif
-	hkMain->finalCmdCB->setText(tr("am Ende \"")+ finalCmd +tr("\" ausführen"));
+	if(finalCmd != "")
+		hkMain->finalCmdCB->setText(tr("am Ende \"")+ finalCmd +tr("\" ausführen"));
+	else
+		hkMain->finalCmdCB->setText(tr("Abschlussbefehl ausführen"));
 	writeConfig();
 	return;
 }
 
+void unsavedChanges(){
+	hkMain->saveTask->setStyleSheet("background-color:rgb(255, 0, 0);\ncolor: white");
+}
+
+void noUnsavedChanges(){
+	hkMain->saveTask->setStyleSheet("");
+}
 
 
 void fillChannels(QComboBox *chanBox){
@@ -456,9 +514,9 @@ void fillTasks(QListWidget *taskList){
 	for(int i=0; i< tasks.count();i++){
 		QString line = *new QString(tasks[i].title)+ " (" + tasks[i].author+ " " 
 			+ tasks[i].chanMnemo + "       " + tasks[i].start.toString("dd.MM.   hh:mm")  + ")";
-		if(tasks[i].unsaved)
+		/*if(tasks[i].unsaved)
 			taskList->addItem(*new QString(QObject::tr("neu")));
-		else if(tasks[i].status == NOW)
+		else */if(tasks[i].status == NOW)
 			taskList->addItem(new QListWidgetItem(nowI,line));
 		else if (tasks[i].status == TODO)
 			taskList->addItem(new QListWidgetItem(todoI,line));
@@ -517,6 +575,7 @@ int main(int argc, char **argv)
 	todoI = QIcon(":/data/todo.png");
 	doneI = QIcon(":/data/done.png");
 	nowI = QIcon(":/data/now.png");
+	notsavedI = QIcon(":/data/notsaved.png");
 	
 	mainW = new QMainWindow;
 	hkMain = new Ui_HKMain;
@@ -526,7 +585,8 @@ int main(int argc, char **argv)
 	
 	hkMain->setupUi(mainW);
 	
-	hkMain->finalCmdCB->setText(app.translate("","am Ende \"")+ finalCmd +app.translate("","\" ausführen"));
+	if(finalCmd != "")
+		hkMain->finalCmdCB->setText(app.translate("","am Ende \"")+ finalCmd +app.translate("","\" ausführen"));
 	fillChannels(hkMain->chanBox);
 	readTasks();
 	fillTasks(hkMain->taskList);
@@ -539,20 +599,36 @@ int main(int argc, char **argv)
                       &l, SLOT(initFileName()));
 	QObject::connect(hkMain->taskList, SIGNAL(currentRowChanged(int)),
                       &l, SLOT(taskSel(int)));
+	QObject::connect(hkMain->taskList, SIGNAL(clicked(QModelIndex)),
+			 &l, SLOT(taskClicked()));
 	QObject::connect(hkMain->chanBox, SIGNAL(currentIndexChanged(int)),
-                      &l, SLOT(chanSel(int)));
+                      &l, SLOT(chanSel()));
 	QObject::connect(hkMain->ftBox, SIGNAL(currentIndexChanged(int)),
                       &l, SLOT(ftSel(int)));
+	QObject::connect(hkMain->fqBox, SIGNAL(currentIndexChanged(int)),
+			 &l, SLOT(guiToTasks()));
 	QObject::connect(hkMain->start, SIGNAL(dateTimeChanged(QDateTime)),
                       &l, SLOT(dateChanged()));
 	QObject::connect(hkMain->stop, SIGNAL(dateTimeChanged(QDateTime)),
                       &l, SLOT(dateChanged()));
 	QObject::connect(hkMain->immAbb, SIGNAL(clicked()),
                       &l, SLOT(immAbb()));
-	QObject::connect(hkMain->saveTask, SIGNAL(clicked()),
-                      &l, SLOT(saveTask()));
 	QObject::connect(hkMain->delTask, SIGNAL(clicked()),
-                      &l, SLOT(delTask()));
+			 &l, SLOT(delTask()));
+	QObject::connect(hkMain->authorEdit, SIGNAL(textChanged()),
+			 &l, SLOT(guiToTasks()));
+	QObject::connect(hkMain->titleEdit, SIGNAL(textChanged()),
+			 &l, SLOT(guiToTasks()));
+	QObject::connect(hkMain->fileEdit, SIGNAL(textChanged()),
+			 &l, SLOT(guiToTasks()));
+	QObject::connect(hkMain->doneCB , SIGNAL(toggled(bool)),
+			 &l, SLOT(guiToTasks()));
+	QObject::connect(hkMain->finalCmdCB , SIGNAL(toggled(bool)),
+			 &l, SLOT(guiToTasks()));
+	
+	
+	QObject::connect(hkMain->saveTask, SIGNAL(clicked()),
+                      &l, SLOT(saveTasks()));
 	QObject::connect(hkMain->newTask, SIGNAL(clicked()),
                       &l, SLOT(newTask()));
 	QObject::connect(hkMain->menubar, SIGNAL(triggered(QAction*)),
