@@ -54,6 +54,9 @@ QString addOnPath="./addons";
 #endif
 
 
+void noUnsavedChanges();
+void unsavedChanges();
+void compareViewTask();
 
 void fillTasks(QListWidget *taskList);
 void Listener::updateTasks(){
@@ -80,7 +83,7 @@ void Listener::chFile(){
 void Listener::immAbb(){
 	int row=0;
 	if(hkMain->taskList->currentRow() < 0){
-		saveTask();
+		saveTasks();
 	} else
 		row = hkMain->taskList->currentRow();
 	logS << "immAbb" << endl;
@@ -144,6 +147,7 @@ void Listener::saveTask(){
 	
 	hkMain->immAbb->setText(tk->status == NOW ? tr("Anhalten") : tr("sofort starten"));
 	hkMain->immAbb->setIcon(tk->status == NOW ? todoI : nowI);
+	noUnsavedChanges();
 	return;
 }
 
@@ -162,6 +166,7 @@ void Listener::delTask(){
 	errorS << "delTask" << endl;
 	tasks.removeAt(hkMain->taskList->currentRow());
 	hkMain->taskList->clearSelection();
+	hkMain->taskSpecificBox->setEnabled(false);
 	errorS << hkMain->taskList->currentRow() << endl;
 	hkMain->taskList->takeItem(hkMain->taskList->currentRow());	
 	writeTasks();
@@ -200,11 +205,14 @@ void Listener::taskSel(int idx){
 	hkMain->finalCmdCB->setChecked(tk.doFinalCmd);
 	hkMain->immAbb->setText(tk.status == NOW ? tr("Anhalten") : tr("sofort starten"));
 	hkMain->immAbb->setIcon(tk.status == NOW ? todoI : nowI);
+	
+	hkMain->taskSpecificBox->setEnabled(true);
 	return;
 }
 
 void Listener::chanSel(int idx){
 	ftSel(hkMain->ftBox->currentIndex());
+	compareViewTask();
 	errorS << idx << endl;
 	return;
 }
@@ -242,8 +250,10 @@ void Listener::ftSel(int idx){
 }
 
 void Listener::dateChanged(){
-	hkMain->doneCB->setChecked(false);
+	if(hkMain->start->dateTime() > hkMain->stop->dateTime())
+		hkMain->stop->setDateTime(hkMain->start->dateTime());
 	errorS << "date changed" << endl;
+	//unsavedChanges();
 	return;
 }
 
@@ -342,6 +352,7 @@ void Listener::respMenuAction(QAction* qa){
 		QGraphicsView *gv = new QGraphicsView(gs,qd);
 		gv->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 		gv->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+		//! this is fundamental on maemo, too
 		gv->resize (aon->width(), aon->height());
 
 		QObject::connect(aon, SIGNAL(finished()),
@@ -437,11 +448,48 @@ void Listener::saveConfig(){
 	monthBeforeDay = confDlg->monthBefDayCB->isChecked();
 	useSchtasks = confDlg->useSchtasksCB->isChecked();
 #endif
-	hkMain->finalCmdCB->setText(tr("am Ende \"")+ finalCmd +tr("\" ausführen"));
+	if(finalCmd != "")
+		hkMain->finalCmdCB->setText(tr("am Ende \"")+ finalCmd +tr("\" ausführen"));
+	else
+		hkMain->finalCmdCB->setText(tr("Abschlussbefehl ausführen"));
 	writeConfig();
 	return;
 }
 
+void unsavedChanges(){
+	hkMain->saveTask->setStyleSheet("background-color:rgb(255, 0, 0);\ncolor: white");
+}
+
+void noUnsavedChanges(){
+	hkMain->saveTask->setStyleSheet("");
+}
+
+void compareViewTask(){
+	int row=0;
+	if(hkMain->taskList->currentRow() < 0){
+		return;
+	} else
+		row = hkMain->taskList->currentRow();
+	logS << "compareViewTask" << endl;
+	Task *tk = &tasks[row];
+	if(tk->start == hkMain->start->dateTime() &&
+		tk->stop == hkMain->stop->dateTime() &&
+		tk->file == hkMain->fileEdit->toPlainText() &&
+		(tk->ft == hkMain->ftBox->currentIndex() - 1) &&
+// 		tk->fq == hkMain->fqBox->currentIndex() &&
+// 		tk->author == hkMain->authorEdit->toPlainText() &&
+// 		tk->title == hkMain->titleEdit->toPlainText() &&
+// 		(tk->status == (int) !hkMain->doneCB->isChecked()) &&
+// 		tk->doFinalCmd == hkMain->finalCmdCB->isChecked() &&
+// 		hkMain->chanBox->currentIndex() >= 0 &&
+// 		tk->chanMnemo == channels[hkMain->chanBox->currentIndex()].mnemo &&
+		tk->chanType == channels[hkMain->chanBox->currentIndex()].type)
+		
+		noUnsavedChanges();
+	else
+		unsavedChanges();
+
+}
 
 
 void fillChannels(QComboBox *chanBox){
@@ -525,7 +573,8 @@ int main(int argc, char **argv)
 	
 	hkMain->setupUi(mainW);
 	
-	hkMain->finalCmdCB->setText(app.translate("","am Ende \"")+ finalCmd +app.translate("","\" ausführen"));
+	if(finalCmd != "")
+		hkMain->finalCmdCB->setText(app.translate("","am Ende \"")+ finalCmd +app.translate("","\" ausführen"));
 	fillChannels(hkMain->chanBox);
 	readTasks();
 	fillTasks(hkMain->taskList);
@@ -549,7 +598,8 @@ int main(int argc, char **argv)
 	QObject::connect(hkMain->immAbb, SIGNAL(clicked()),
                       &l, SLOT(immAbb()));
 	QObject::connect(hkMain->saveTask, SIGNAL(clicked()),
-                      &l, SLOT(saveTask()));
+                      &l, SLOT(saveTasks
+()));
 	QObject::connect(hkMain->delTask, SIGNAL(clicked()),
                       &l, SLOT(delTask()));
 	QObject::connect(hkMain->newTask, SIGNAL(clicked()),
